translate.convert.convert.Replacer

Package translate :: Package convert :: Module convert :: Class Replacer |
[hide private]
[frames] | no frames]

# Class Replacer

source code

an object that knows how to replace strings in files

Instance Methods | [hide private]
__init__(self, searchstring, replacestring) | source code
doreplace(self, text) actually replace the text | source code
searchreplaceinput(self, inputfile, outputfile, templatefile, **kwargs) copies the input file to the output file, searching and replacing | source code
searchreplacetemplate(self, inputfile, outputfile, templatefile, **kwargs) copies the template file to the output file, searching and replacing | source code